The HentaiVerse

9703
459
602
142
Battle Time
Choose from the Battle Actions highlighted above, and use them to defeat your enemies listed to the right. When all enemies are reduced to zero Health, you win. If your Health reaches zero, you are defeated.

Super Spirit crits you, causing 252 points of Piercing damage.
Super Spirit hits you, causing 224 points of Piercing damage.
Spirit Stance Engaged
The effect Protection was dispelled.
You gain the effect Protection.
You use Scroll of Protection.
Spawned Monster D: MID=83605 (So Week) LV=224 HP=24998
Spawned Monster C: MID=31124 (Super Spirit) LV=224 HP=23212
Spawned Monster B: MID=166576 (Go Cry Go) LV=224 HP=25544
Spawned Monster A: MID=253761 (Lyrica Prismriver) LV=224 HP=11941
Initializing arena challenge #23 (Round 2 / 55) ...

Round 2 / 55
⚙